@@ -62,6 +62,8 @@ pub trait DubpBlockTrait {
     fn compute_hashed_string(&self) -> String;
     /// Compute the character string that will be signed
     fn compute_signed_string(&self) -> String;
+    /// Get currency name
+    fn currency_name(&self) -> CurrencyName;
     /// Get currency parameters
     fn currency_parameters(&self) -> Option<CurrencyParameters>;
     /// Get current frame size (in blocks)
@@ -139,6 +141,7 @@ impl DubpBlockTrait for DubpBlock {
     dubp_block_fn!(compute_hash, BlockHash);
     dubp_block_fn!(compute_hashed_string, String);
     dubp_block_fn!(compute_signed_string, String);
+    dubp_block_fn!(currency_name, CurrencyName);
     dubp_block_fn!(currency_parameters, Option<CurrencyParameters>);
     dubp_block_fn!(current_frame_size, usize);
     dubp_block_fn!(dividend, Option<SourceAmount>);
